Method: ActivityNotification::NotificationApi#group_notification_count
- Defined in:
- lib/activity_notification/apis/notification_api.rb
#group_notification_count(limit = ActivityNotification.config.opened_index_limit) ⇒ Integer
Returns count of group notifications including owner and members. This method is designed to cache group by query result to avoid N+1 call.
635 636 637 |
# File 'lib/activity_notification/apis/notification_api.rb', line 635 def group_notification_count(limit = ActivityNotification.config.opened_index_limit) group_member_count(limit) + 1 end |